import { RevertableEvent } from "@skeldjs/events";
import { RepairSystemMessage } from "@skeldjs/protocol";
import { RoomEvent } from "../RoomEvent";
import { ProtocolEvent } from "../ProtocolEvent";
import { HeliSabotageEvent } from "./HeliSabotageEvent";
import { Hostable } from "../../Hostable";
import { HeliSabotageSystem } from "../../systems";
import { PlayerData } from "../../PlayerData";
/**
 * Emitted when a player completes a console while the heli is sabotaged on Airship.
 */
export declare class HeliSabotageConsoleCompleteEvent<RoomType extends Hostable = Hostable> extends RevertableEvent implements RoomEvent, HeliSabotageEvent, ProtocolEvent {
    readonly room: RoomType;
    readonly helisabotagesystem: HeliSabotageSystem<RoomType>;
    readonly message: RepairSystemMessage | undefined;
    /**
     * The player that completed the console. Only availabe if the client
     * is the host.
     */
    readonly player: PlayerData<RoomType> | undefined;
    /**
     * The ID of the console that was completed.
     */
    readonly consoleId: number;
    static eventName: "heli.consoles.complete";
    eventName: "heli.consoles.complete";
    private _alteredConsoleId;
    constructor(room: RoomType, helisabotagesystem: HeliSabotageSystem<RoomType>, message: RepairSystemMessage | undefined, 
    /**
     * The player that completed the console. Only availabe if the client
     * is the host.
     */
    player: PlayerData<RoomType> | undefined, 
    /**
     * The ID of the console that was completed.
     */
    consoleId: number);
    /**
     * The ID of the alternate console that will be completed, if changed.
     */
    get alteredConsoleId(): number;
    /**
     * Change the ID of the console that was completed.
     * @param consoleId The ID of the console to complete.
     */
    setConsoleId(consoleId: number): void;
}
