import { CancelableEvent } from "@skeldjs/events";
import { Hostable } from "../../Hostable";
import { PlayerData } from "../../PlayerData";
import { RoomEvent } from "../RoomEvent";
/**
 * Emitted when the room picks which impostors will be selected, after the game
 * is started. Can be canceled to avoid choosing and setting impostors altogether.
 *
 * Mainly emitted in order to allow overriding of the default impostor
 * selection in SkeldJS.
 */
export declare class RoomSelectImpostorsEvent<RoomType extends Hostable = Hostable> extends CancelableEvent implements RoomEvent {
    readonly room: RoomType;
    /**
     * The players that were chosen to be impostors.
     */
    readonly impostors: PlayerData<RoomType>[];
    static eventName: "room.selectimpostors";
    eventName: "room.selectimpostors";
    private _alteredImpostors;
    constructor(room: RoomType, 
    /**
     * The players that were chosen to be impostors.
     */
    impostors: PlayerData<RoomType>[]);
    /**
     * The altered impostor list that will be used instead, if changed.
     */
    get alteredImpostors(): PlayerData<RoomType>[];
    /**
     * Change the players that were selected.
     * @param impostors The players to select.
     */
    setImpostors(impostors: PlayerData<RoomType>[]): void;
}
