import { HazelReader, HazelWriter } from "@skeldjs/util";
import { Color, Hat, Pet, Skin } from "@skeldjs/constant";
import { GameData } from "../objects";
import { Hostable } from "../Hostable";
export declare class TaskState {
    taskidx: number;
    completed: boolean;
    constructor(taskidx: number, completed: boolean);
    static Deserialize(reader: HazelReader): TaskState;
    Deserialize(reader: HazelReader): void;
    Serialize(writer: HazelWriter): void;
}
/**
 * Represents a player's information, name, color, hat, etc.
 */
export declare class PlayerInfo<RoomType extends Hostable = Hostable> {
    readonly gamedata: GameData<RoomType>;
    playerId: number;
    name: string;
    color: number;
    hat: Hat;
    pet: Pet;
    skin: Skin;
    flags: number;
    taskIds: number[];
    taskStates: TaskState[];
    constructor(gamedata: GameData<RoomType>, playerId: number, name?: string, color?: number, hat?: Hat, pet?: Pet, skin?: Skin, flags?: number, taskIds?: number[], taskStates?: TaskState[]);
    /**
     * The player that this info is for.
     */
    get player(): import("..").PlayerData<RoomType> | undefined;
    /**
     * Whether this player has been flagged as disconnected.
     */
    get isDisconnected(): boolean;
    /**
     * Whether this player has been flagged as the impostor.
     */
    get isImpostor(): boolean;
    /**
     * Whether this player has been flagged as dead.
     */
    get isDead(): boolean;
    /**
     * Create a default player info object.
     * @param gamedata The gamedata object that this player information belongs to.
     * @param playerId The ID of the player.
     * @returns A default player info object.
     */
    static createDefault<RoomType extends Hostable = Hostable>(gamedata: GameData<RoomType>, playerId: number): PlayerInfo<RoomType>;
    static Deserialize<RoomType extends Hostable = Hostable>(reader: HazelReader, gamedata: GameData<RoomType>, playerId: number): PlayerInfo<RoomType>;
    Deserialize(reader: HazelReader): void;
    Serialize(writer: HazelWriter): void;
    /**
     * Clone the player info for another player.
     */
    clone(playerId: number): PlayerInfo<RoomType>;
    /**
     * Set whether this player is flagged as disconnected.
     */
    setDisconnected(isDisconnected: boolean): void;
    /**
     * Set whether this player is flagged as an impostor.
     */
    setImpostor(isImpostor: boolean): void;
    /**
     * Set whether this player is flagged as dead.
     */
    setDead(isDead: boolean): void;
    /**
     * Set the name of this player.
     */
    setName(name: string): void;
    /**
     * Set the color of this player.
     */
    setColor(color: Color): void;
    /**
     * Set the hat of this player.
     */
    setHat(hat: Hat): void;
    /**
     * Set the pet of this player.
     */
    setPet(pet: Pet): void;
    /**
     * Set the skin of this player.
     */
    setSkin(skin: Skin): void;
    /**
     * Set the flags of this player.
     */
    setFlags(flags: number): void;
    /**
     * Set the tasks of this player.
     * @param taskIds The IDs of each task.
     */
    setTaskIds(taskIds: number[]): void;
    /**
     * Set the task states of this player.
     */
    setTaskStates(taskStates: TaskState[]): void;
    /**
     * Mark a task of this player as completed.
     */
    completeTask(state: TaskState): void;
}
