"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.PolusShipStatus = void 0;
const constant_1 = require("@skeldjs/constant");
const util_1 = require("@skeldjs/util");
const systems_1 = require("../systems");
const Door_1 = require("../misc/Door");
const InnerShipStatus_1 = require("./InnerShipStatus");
/**
 * Represents a room object for the Polus map.
 *
 * See {@link ShipStatusEvents} for events to listen to.
 */
class PolusShipStatus extends InnerShipStatus_1.InnerShipStatus {
    constructor(room, spawnType, netid, ownerid, flags, data) {
        super(room, spawnType, netid, ownerid, flags, data);
        this.initialSpawnCenter = new util_1.Vector2(16.64, 2.2);
        this.meetingSpawnCenter = new util_1.Vector2(17.726, -16.286);
        this.meetingSpawnCenter2 = new util_1.Vector2(17.726, -17.515);
    }
    getComponent(component) {
        if (component === PolusShipStatus) {
            return this.components[0];
        }
        return undefined;
    }
    Setup() {
        this.systems.set(constant_1.SystemType.Electrical, new systems_1.SwitchSystem(this, constant_1.SystemType.Electrical, {
            expected: [false, false, false, false, false],
            actual: [false, false, false, false, false],
            brightness: 255,
        }));
        this.systems.set(constant_1.SystemType.MedBay, new systems_1.MedScanSystem(this, constant_1.SystemType.MedBay, {
            queue: [],
        }));
        this.systems.set(constant_1.SystemType.Security, new systems_1.SecurityCameraSystem(this, constant_1.SystemType.Security, {
            players: new Set,
        }));
        this.systems.set(constant_1.SystemType.Communications, new systems_1.HudOverrideSystem(this, constant_1.SystemType.Communications, {
            sabotaged: false,
        }));
        this.systems.set(constant_1.SystemType.Doors, new systems_1.DoorsSystem(this, constant_1.SystemType.Doors, {
            doors: [],
            cooldowns: new Map,
        }));
        this.systems.set(constant_1.SystemType.Sabotage, new systems_1.SabotageSystem(this, constant_1.SystemType.Sabotage, {
            cooldown: 0,
        }));
        this.systems.set(constant_1.SystemType.Decontamination, new systems_1.DeconSystem(this, constant_1.SystemType.Decontamination, {
            timer: 10000,
            state: 0,
        }));
        this.systems.set(constant_1.SystemType.Decontamination2, new systems_1.DeconSystem(this, constant_1.SystemType.Decontamination2, {
            timer: 10000,
            state: 0,
        }));
        this.systems.set(constant_1.SystemType.Laboratory, new systems_1.ReactorSystem(this, constant_1.SystemType.Laboratory, {
            timer: 10000,
            completed: new Set,
        }));
        const doorsystem = this.systems.get(constant_1.SystemType.Doors);
        doorsystem.doors = [
            new Door_1.Door(doorsystem, 0, true),
            new Door_1.Door(doorsystem, 1, true),
            new Door_1.Door(doorsystem, 2, true),
            new Door_1.Door(doorsystem, 3, true),
            new Door_1.Door(doorsystem, 4, true),
            new Door_1.Door(doorsystem, 5, true),
            new Door_1.Door(doorsystem, 6, true),
            new Door_1.Door(doorsystem, 7, true),
            new Door_1.Door(doorsystem, 8, true),
            new Door_1.Door(doorsystem, 9, true),
            new Door_1.Door(doorsystem, 10, true),
            new Door_1.Door(doorsystem, 11, true),
        ];
    }
    getSpawnPosition(player, initialSpawn) {
        const playerId = typeof player === "number"
            ? player
            : player.playerId;
        if (initialSpawn) {
            return super.getSpawnPosition(player, initialSpawn);
        }
        const num = ~~(this.room.players.size / 2);
        const num2 = playerId % 15;
        if (num2 < num) {
            const step = util_1.Vector2.right.mul(num2).mul(0.6);
            return this.meetingSpawnCenter
                .add(step);
        }
        else {
            const step = util_1.Vector2.right.mul(num2 - num).mul(0.6);
            return this.meetingSpawnCenter2
                .add(step);
        }
    }
    getDoorsInRoom(room) {
        return PolusShipStatus.roomDoors[room] || [];
    }
}
exports.PolusShipStatus = PolusShipStatus;
PolusShipStatus.roomDoors = {
    [constant_1.SystemType.Electrical]: [0, 1, 2],
    [constant_1.SystemType.O2]: [3, 4],
    [constant_1.SystemType.Weapons]: [5],
    [constant_1.SystemType.Communications]: [7],
    [constant_1.SystemType.Office]: [7, 8],
    [constant_1.SystemType.Laboratory]: [9, 10],
    [constant_1.SystemType.Storage]: [11],
    [constant_1.SystemType.Decontamination]: [12, 13, 14, 15]
};
//# sourceMappingURL=PolusShipStatus.js.map